@@ -26,6 +26,8 @@ from runnerase.symmetryfunctions import SymmetryFunctionSet
 from runnerase.defaultoptions import DEFAULT_PARAMETERS
 from runnerase.utils import get_elements
 
+from runnerase.plot import RunnerPlots
+
 
 # RuNNer class inherits from FileIOCalculator and therefore requires a lot
 # of instance attributes and ancestors.
@@ -255,7 +257,7 @@ class Runner(FileIOCalculator):
         # If no elements were specified, set them automatically based on the
         # attached dataset or Atoms object.
         if elements is None:
-            images = self.dataset or [self.atoms]
+            images = self.dataset or [self.atoms]  # type: ignore
 
             # Elements will either be extracted from the training dataset or
             # from the `Atoms` object to which the calculator has been attached.
@@ -297,8 +299,7 @@ class Runner(FileIOCalculator):
 
     def run(
         self,
-        mode: Optional[int] = None,
-        label: Optional[str] = None
+        mode: Optional[int] = None
     ) -> None:
         """Execute RuNNer Mode 1, 2, or 3.
 
@@ -307,10 +308,6 @@ class Runner(FileIOCalculator):
         mode : int
             The RuNNer mode that will be executed. If not given,
             `self.parameters.runner_mode` will be evaluated.
-        label : string
-            The label of the calculation. By default, RuNNer Mode X calculations
-            are stored in a separate folder with the name 'modeX' and output
-            files carry the `PREFIX` 'modeX'.
 
         Raises
         ------
@@ -327,12 +324,11 @@ class Runner(FileIOCalculator):
             self.set(runner_mode=mode)
 
         # Set the correct calculation label.
-        if label is None:
-            self.label = None
-            self.directory = f'mode{mode}'
+        if self.prefix is None:  # type: ignore
             self.prefix = f'mode{mode}'
-        else:
-            self.label = label
+
+        if self.label is None:  # type: ignore
+            self.label = f'{self.directory}/mode{mode}/mode{mode}'
 
         # Set the correct elements of the system.
         self.set_elements()
@@ -341,7 +337,7 @@ class Runner(FileIOCalculator):
         # which the calculator has been attached (`self.atoms`) or for the
         # whole dataset (`self.dataset`).
         # `dataset` takes precedence over the attached `atoms` object.
-        atoms = self.dataset or self.atoms
+        atoms = self.dataset or self.atoms  # type: ignore
 
         # If neither `self.dataset` nor `self.atoms` has been defined yet,
         # raise an error.
@@ -380,6 +376,7 @@ class Runner(FileIOCalculator):
 
         # Read in the dataset, the parameters and the results.
         structures, self.parameters = io.read_runnerase(label)
+
         if isinstance(structures, list):
             self.dataset = structures
         else:
@@ -559,3 +556,11 @@ class Runner(FileIOCalculator):
         self.parameters['runner_mode'] = 3
         self.parameters['calculate_stress'] = True
         return super().get_stress(atoms)
+
+    @property
+    def plot(self) -> RunnerPlots:
+        """Create a plotting interface."""
+        if self.dataset is None:
+            raise RuntimeError('Please attach a dataset to the calculator '
+                               + 'to generate plots.')
+        return RunnerPlots(self.dataset, self.results)
