@@ -77,7 +77,7 @@ def read(
         images = read_runnerdata(filename, index=index)
         return next(images)
 
-    images = aseread(filename, index, format=format)
+    images = aseread(filename.name, index, format=format)
     return images
 
 
@@ -130,7 +130,7 @@ def read_runnerase(
         A dictionary containing all RuNNer settings of the calculation.
     """
     # Extract the directory path.
-    directory = ''.join(label.split('/')[:-1])
+    directory = '/'.join(label.split('/')[:-1])
 
     # Join the paths to all relevant files.
     inputdata_path = os.path.join(directory, 'input.data')
