@@ -121,7 +121,7 @@ class SymmetryFunctionSetPlots(GenericPlots):
 
                     # Generate the label.
                     label = r'$\eta = $' + f'{symfun.coefficients[0]:.3f}' \
-                            + r' $a_0^2$,' \
+                            + r' $a_0^{-2}$,' \
                             + r' $R_\mathrm{s} = $' \
                             + f'{symfun.coefficients[1]:.3f}'
 
