@@ -41,7 +41,8 @@ from runnerase.plot import (RunnerSplitTrainTestPlots,
                             RunnerSymmetryFunctionValuesPlots,
                             RunnerStructureSymmetryFunctionValuesPlots,
                             RunnerFitResultsPlots,
-                            RunnerScalingPlots)
+                            RunnerScalingPlots,
+                            RunnerWeightsPlots)
 
 
 class ElementStorageMixin:
@@ -377,6 +378,11 @@ class RunnerWeights(ElementStorageMixin):
             element_path = os.path.join(path, f'{prefix}.{number:03d}.{suffix}')
             np.savetxt(element_path, weights, fmt='%.10f')
 
+    @property
+    def plot(self) -> RunnerWeightsPlots:
+        """Create a plotting interface."""
+        return RunnerWeightsPlots(self.data)
+
 
 class RunnerStructureSymmetryFunctionValues(ElementStorageMixin):
     """Storage container for the symmetry function values of one structure."""
