@@ -178,6 +178,15 @@ class SymmetryFunction:
 
         return string
 
+    def todict(self):
+        """Return a dictionary representation of the object."""
+        return {
+            'sftype': self.sftype,
+            'cutoff': self.cutoff,
+            'elements': self.elements,
+            'coefficients': self.coefficients
+        }
+
     def to_list(self) -> SFListType:
         """Create a list representation of the symmetry function."""
         if (self.elements is None or self.coefficients is None
@@ -281,6 +290,14 @@ class SymmetryFunctionSet:
         for symmetryfunction in self.storage:
             yield symmetryfunction
 
+    def todict(self):
+        """Return a dictionary representation of the object."""
+        return {
+            'sets': self._sets,
+            'symmetryfunctions': self._symmetryfunctions,
+            'min_distances': self.min_distances
+        }
+
     def to_list(self) -> List[SFListType]:
         """Create a list of all stored symmetryfunctions."""
         symmetryfunction_list = []
